/*
 * Asterisk -- A telephony toolkit for Linux.
 *
 * Pluggable PBX Example
 *
 * Copyright (C) 2005, Anthony Minessale II
 *
 * Anthony Minessale II <anthmct@yahoo.com>
 *
 * This program is free software, distributed under the terms of
 * the GNU General Public License
 */

#include <asterisk/file.h>
#include <asterisk/logger.h>
#include <asterisk/channel.h>
#include <asterisk/pbx.h>
#include <asterisk/options.h>
#include <asterisk/module.h>
#include <asterisk/lock.h>
#include <stdlib.h>
#include <unistd.h>
#include <string.h>

static char *tdesc = "Demonstration of Asterisk Pluggable PBX.";

STANDARD_LOCAL_USER;

LOCAL_USER_DECL;


static int my_pbx_exec(struct ast_channel *chan) 
{
	int res = 0;
	struct localuser *u;
	LOCAL_USER_ADD(u);
	ast_verbose(VERBOSE_PREFIX_2 "Demo PBX called on chan %s\n", chan->name);

	ast_verbose(VERBOSE_PREFIX_3 "Gonna Play a file on %s it's all me here so I gotta do all my own verbosity\n", chan->name);
	if(!ast_streamfile(chan, "demo-thanks", chan->language)) {
		ast_waitstream(chan, "");
	}
	LOCAL_USER_REMOVE(u);

	ast_verbose(VERBOSE_PREFIX_2 "Demo PBX gonna destroy the channel  %s now bye bye!\n", chan->name);
	ast_hangup(chan);
	return 0;
}

static struct ast_pluggable_pbx my_pbx = {
	.name = "MyPBX",
	.desc = "Demo PBX",
	.run = my_pbx_exec,
};


int unload_module(void)
{
	STANDARD_HANGUP_LOCALUSERS;
	return ast_pbx_unregister(&my_pbx);
}

int load_module(void)
{
	return ast_pbx_register(&my_pbx);
}

char *description(void)
{
	return tdesc;
}

int usecount(void)
{
	int res;
	STANDARD_USECOUNT(res);
	return res;
}

char *key()
{
	return ASTERISK_GPL_KEY;
}

